@@ -31,13 +31,11 @@ lock = Lock()
 
 
 class DocumentFileRepository:
-    def __init__(self, dir_path: Path, recursive=False, lang=settings['lang'], use_ocr=settings['ocr'],
-                 doc_path_filter=None):
-        self.lang = lang
+    def __init__(self, dir_path: Path, recursive=False, lang=None, use_ocr=None):
+        self.lang = lang if lang else settings['lang']
         self.dir_path = dir_path
-        self._use_ocr = use_ocr
+        self._use_ocr = use_ocr if use_ocr else settings['ocr']
         self._recursive = recursive
-        self._doc_path_filter = doc_path_filter
         if not dir_path.is_dir():
             raise NotADirectoryError(f'The given path {dir_path} does not point to an existing directory!')
 
@@ -48,14 +46,13 @@ class DocumentFileRepository:
             return (file for file in self.dir_path.iterdir() if file.is_file() and file.suffix != '.pdef')
 
     def list(self) -> set[models.Document]:
-        files = list(filter(lambda f: not self._doc_path_filter or str(f.resolve()) in self._doc_path_filter,
-                            self._list_files()))
+        files = list(self._list_files())
         docs = process_map(self._read_file, files, desc=f"Reading documents in '{self.dir_path}'",
                            unit='doc', total=len(files), max_workers=os.cpu_count())
         return set(filter(None, docs))
 
     def _read_file(self, file):
-        if file.suffix == '.pdf':
+        if file.suffix.lower() == '.pdf':
             reader = PdfReader(file, self.lang, self._use_ocr)
             text = reader.extract_text()
             return models.Document(file.stem, str(file.resolve()), text)
@@ -72,6 +69,14 @@ class DocumentFileRepository:
                 log.debug('Following error occurred:', exc_info=True)
 
 
+class DocumentPairRepository:
+    def __init__(self, doc1: models.Document, doc2: models.Document):
+        self._docs = {doc1, doc2}
+
+    def list(self) -> set[models.Document]:
+        return self._docs
+
+
 class DocumentPairMatchesJsonRepository:
     def __init__(self, out_path: Path):
         if not out_path.is_dir():
